==> com.liferay.layout.admin.web-3.0.23.jar: META-INF/resources/js/LayoutPrototypeDropdownDefaultEventHandler.es.js <==
"use strict";

Liferay.Loader.define("layout-admin-web@3.0.23/js/LayoutPrototypeDropdownDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web/liferay/DefaultEventHandler.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  var _DefaultEventHandler2 = _interopRequireDefault(require("frontend-js-web/liferay/DefaultEventHandler.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var LayoutPrototypeDropdownDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(LayoutPrototypeDropdownDefaultEventHandler, _DefaultEventHandler);

    function LayoutPrototypeDropdownDefaultEventHandler() {
      _classCallCheck(this, LayoutPrototypeDropdownDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(LayoutPrototypeDropdownDefaultEventHandler).apply(this, arguments));
    }

    _createClass(LayoutPrototypeDropdownDefaultEventHandler, [{
      key: "deleteLayoutPrototype",
      value: function deleteLayoutPrototype(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-delete-this'))) {
          this._send(itemData.deleteLayoutPrototypeURL);
        }
      }
    }, {
      key: "exportLayoutPrototype",
      value: function exportLayoutPrototype(itemData) {
        this._openWindow('export', itemData.exportLayoutPrototypeURL);
      }
    }, {
      key: "importLayoutPrototype",
      value: function importLayoutPrototype(itemData) {
        this._openWindow('import', itemData.importLayoutPrototypeURL);
      }
    }, {
      key: "permissionsLayoutPrototype",
      value: function permissionsLayoutPrototype(itemData) {
        this._openWindow('permissions', itemData.permissionsLayoutPrototypeURL);
      }
    }, {
      key: "_openWindow",
      value: function _openWindow(label, url) {
        Liferay.Util.openWindow({
          dialog: {
            destroyOnHide: true,
            modal: true
          },
          dialogIframe: {
            bodyCssClass: 'dialog-with-footer'
          },
          title: Liferay.Language.get(label),
          uri: url
        });
      }
    }, {
      key: "_send",
      value: function _send(url) {
        submitForm(document.hrefFm, url);
      }
    }]);

    return LayoutPrototypeDropdownDefaultEventHandler;
  }(_DefaultEventHandler2.default);

  var _default = LayoutPrototypeDropdownDefaultEventHandler;
  exports.default = _default;
  //# sourceMappingURL=LayoutPrototypeDropdownDefaultEventHandler.es.js.map
});
//# sourceMappingURL=LayoutPrototypeDropdownDefaultEventHandler.es.js.map

==> com.liferay.layout.admin.web-3.0.87.jar: META-INF/resources/js/LayoutPrototypeDropdownDefaultEventHandler.es.js <==
Liferay.Loader.define("layout-admin-web@3.0.87/js/LayoutPrototypeDropdownDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var LayoutPrototypeDropdownDefaultEventHandler = /*#__PURE__*/function (_DefaultEventHandler) {
    _inherits(LayoutPrototypeDropdownDefaultEventHandler, _DefaultEventHandler);

    function LayoutPrototypeDropdownDefaultEventHandler() {
      _classCallCheck(this, LayoutPrototypeDropdownDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(LayoutPrototypeDropdownDefaultEventHandler).apply(this, arguments));
    }

    _createClass(LayoutPrototypeDropdownDefaultEventHandler, [{
      key: "deleteLayoutPrototype",
      value: function deleteLayoutPrototype(itemData) {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-delete-this'))) {
          this._send(itemData.deleteLayoutPrototypeURL);
        }
      }
    }, {
      key: "exportLayoutPrototype",
      value: function exportLayoutPrototype(itemData) {
        this._openWindow('export', itemData.exportLayoutPrototypeURL);
      }
    }, {
      key: "importLayoutPrototype",
      value: function importLayoutPrototype(itemData) {
        this._openWindow('import', itemData.importLayoutPrototypeURL);
      }
    }, {
      key: "permissionsLayoutPrototype",
      value: function permissionsLayoutPrototype(itemData) {
        this._openWindow('permissions', itemData.permissionsLayoutPrototypeURL);
      }
    }, {
      key: "_openWindow",
      value: function _openWindow(label, url) {
        Liferay.Util.openWindow({
          dialog: {
            destroyOnHide: true,
            modal: true
          },
          dialogIframe: {
            bodyCssClass: 'dialog-with-footer'
          },
          title: Liferay.Language.get(label),
          uri: url
        });
      }
    }, {
      key: "_send",
      value: function _send(url) {
        submitForm(document.hrefFm, url);
      }
    }]);

    return LayoutPrototypeDropdownDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  var _default = LayoutPrototypeDropdownDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=LayoutPrototypeDropdownDefaultEventHandler.es.js.map
});
//# sourceMappingURL=LayoutPrototypeDropdownDefaultEventHandler.es.js.map
